# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


import re  # noqa: F401
import sys  # noqa: F401

from datadog_api_client.v1.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
)


def lazy_import():
    from datadog_api_client.v1.model.apm_stats_query_definition import ApmStatsQueryDefinition
    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
    from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition
    from datadog_api_client.v1.model.table_widget_cell_display_mode import TableWidgetCellDisplayMode
    from datadog_api_client.v1.model.widget_aggregator import WidgetAggregator
    from datadog_api_client.v1.model.widget_conditional_format import WidgetConditionalFormat
    from datadog_api_client.v1.model.widget_sort import WidgetSort

    globals()["ApmStatsQueryDefinition"] = ApmStatsQueryDefinition
    globals()["LogQueryDefinition"] = LogQueryDefinition
    globals()["ProcessQueryDefinition"] = ProcessQueryDefinition
    globals()["TableWidgetCellDisplayMode"] = TableWidgetCellDisplayMode
    globals()["WidgetAggregator"] = WidgetAggregator
    globals()["WidgetConditionalFormat"] = WidgetConditionalFormat
    globals()["WidgetSort"] = WidgetSort


class TableWidgetRequest(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {}

    validations = {}

    additional_properties_type = None

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            "aggregator": (WidgetAggregator,),  # noqa: E501
            "alias": (str,),  # noqa: E501
            "apm_query": (LogQueryDefinition,),  # noqa: E501
            "apm_stats_query": (ApmStatsQueryDefinition,),  # noqa: E501
            "cell_display_mode": ([TableWidgetCellDisplayMode],),  # noqa: E501
            "conditional_formats": ([WidgetConditionalFormat],),  # noqa: E501
            "event_query": (LogQueryDefinition,),  # noqa: E501
            "limit": (int,),  # noqa: E501
            "log_query": (LogQueryDefinition,),  # noqa: E501
            "network_query": (LogQueryDefinition,),  # noqa: E501
            "order": (WidgetSort,),  # noqa: E501
            "process_query": (ProcessQueryDefinition,),  # noqa: E501
            "profile_metrics_query": (LogQueryDefinition,),  # noqa: E501
            "q": (str,),  # noqa: E501
            "rum_query": (LogQueryDefinition,),  # noqa: E501
            "security_query": (LogQueryDefinition,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None

    attribute_map = {
        "aggregator": "aggregator",  # noqa: E501
        "alias": "alias",  # noqa: E501
        "apm_query": "apm_query",  # noqa: E501
        "apm_stats_query": "apm_stats_query",  # noqa: E501
        "cell_display_mode": "cell_display_mode",  # noqa: E501
        "conditional_formats": "conditional_formats",  # noqa: E501
        "event_query": "event_query",  # noqa: E501
        "limit": "limit",  # noqa: E501
        "log_query": "log_query",  # noqa: E501
        "network_query": "network_query",  # noqa: E501
        "order": "order",  # noqa: E501
        "process_query": "process_query",  # noqa: E501
        "profile_metrics_query": "profile_metrics_query",  # noqa: E501
        "q": "q",  # noqa: E501
        "rum_query": "rum_query",  # noqa: E501
        "security_query": "security_query",  # noqa: E501
    }

    _composed_schemas = {}

    required_properties = set(
        [
            "_data_store",
            "_check_type",
            "_spec_property_naming",
            "_path_to_item",
            "_configuration",
            "_visited_composed_classes",
        ]
    )

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """TableWidgetRequest - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            aggregator (WidgetAggregator): [optional]  # noqa: E501
            alias (str): The column name (defaults to the metric name).. [optional]  # noqa: E501
            apm_query (LogQueryDefinition): [optional]  # noqa: E501
            apm_stats_query (ApmStatsQueryDefinition): [optional]  # noqa: E501
            cell_display_mode ([TableWidgetCellDisplayMode]): A list of display modes for each table cell.. [optional]  # noqa: E501
            conditional_formats ([WidgetConditionalFormat]): List of conditional formats.. [optional]  # noqa: E501
            event_query (LogQueryDefinition): [optional]  # noqa: E501
            limit (int): For metric queries, the number of lines to show in the table. Only one request should have this property.. [optional]  # noqa: E501
            log_query (LogQueryDefinition): [optional]  # noqa: E501
            network_query (LogQueryDefinition): [optional]  # noqa: E501
            order (WidgetSort): [optional]  # noqa: E501
            process_query (ProcessQueryDefinition): [optional]  # noqa: E501
            profile_metrics_query (LogQueryDefinition): [optional]  # noqa: E501
            q (str): Query definition.. [optional]  # noqa: E501
            rum_query (LogQueryDefinition): [optional]  # noqa: E501
            security_query (LogQueryDefinition): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop("_check_type", True)
        _spec_property_naming = kwargs.pop("_spec_property_naming", False)
        _path_to_item = kwargs.pop("_path_to_item", ())
        _configuration = kwargs.pop("_configuration", None)
        _visited_composed_classes = kwargs.pop("_visited_composed_classes", ())

        if args:
            raise ApiTypeError(
                "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments."
                % (
                    args,
                    self.__class__.__name__,
                ),
                path_to_item=_path_to_item,
                valid_classes=(self.__class__,),
            )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        for var_name, var_value in kwargs.items():
            if (
                var_name not in self.attribute_map
                and self._configuration is not None
                and self._configuration.discard_unknown_keys
                and self.additional_properties_type is None
            ):
                # discard variable.
                continue
            setattr(self, var_name, var_value)
